@@ -32,6 +32,7 @@ syntax() {
    echo "	--plot -p - Print plot."
    echo "	--year -y - Print year."
    echo "	--cast -C - Print cast."
+   echo "       --rating -R - Print rating."
    echo "	--cover -c - Print cover art URI."
    echo "	--print-filename -m - Print filename."
    echo "	--all -a - Print all details."
@@ -116,6 +117,7 @@ doIMDB() {
    doItem $TEMP "$SAVE" '/<h5>Genre:<\/h5>/,+1s/[<(][^>)]*[>)]//g;/^Genre:/,+1s/\(.*\)).*/\1/p' genre $1 $GENRE
    doItem $TEMP "$SAVE" '/<table class="cast">/ {s|^.*<table class="cast"> *||;s|<form action.*||;s|\([0-9a-z)]\)\([A-Z]\)|\1::\2|g;s|>more.*|>|;s|<[^>]*>||g;s|\([0-9a-z)]\)\([A-Z]\)|\1, \2|g;s|::||g;s| \.\.\. | as |gp}' cast $1 $CAST
    doItem $TEMP "$SAVE" '/^<a name="poster"/s,SY140_SX100,SY400_SX600,;s,<a name="poster".*<img .*src="\([^"]*\).*</a>,\1,p' coverart $1 $COVER
+   doItem $TEMP "$SAVE" '/^<b>.*\/10<\/b>/s,<b>\(.*\)\/10<\/b>,\1,p' rating $1 $RATING
 
    if [[ "$RENAME" == "true" ]]; then
        OLDFILE="$FILENAME"
@@ -216,7 +218,7 @@ doSearch() {
    else
       TEMPCHOICES=`mktemp`
       files=("${files[@]}" "$TEMPCHOICES")
-      < $TEMP tidy -iq -w 1000 2>/dev/null | sed 's/t\([dr][^>]*\)>/t\1>\n/g' | sed -n '/^ *<a href="\/title\/tt/s,^ *<a href="/title/\(tt[0-9]*\)/">\([^<]*\)</a>\([^<]*\)<.*,\1%\2 \3,p' > $TEMPCHOICES
+      < $TEMP tidy -iq -w 1000 2>/dev/null | sed 's/t\([dr][^>]*\)>/t\1>\n/g' | sed -n '/^ *<a href="\/title\/tt/s,^ *<a href="/title/\(tt[0-9]*\)/".*>\([^<]\+\)</a>\([^<]*\)<.*,\1%\2 \3,p' > $TEMPCHOICES
       (( i = 1 ))
       IFS='
 '
@@ -227,7 +229,7 @@ doSearch() {
       done
       
       echo -n "Select a Film: "
-      read n
+      read n </dev/tty
       IMDB=`head -n $n $TEMPCHOICES | tail -n1 | cut -d% -f1`
       if [[ "$IMDB" == "" ]]; then
          echo "Find aborted"
@@ -304,6 +306,9 @@ while [[ "$1" != "" ]]; do
       --director|-D)
          DIRECTOR=true
          ;;
+      --rating|-R)
+	 RATING=true
+         ;;
       --writer|-w)
          WRITER=true
          ;;
@@ -347,6 +352,7 @@ while [[ "$1" != "" ]]; do
          PLOT=true	
          TITLE=true
          YEAR=true
+	 RATING=true
          ID=true
          PRINTFILE=true
          ;;
@@ -368,6 +374,7 @@ if [[ "$COVER" != "true" &&
       "$WRITER" != "true" &&
       "$TAG" != "true" &&
       "$PLOT" != "true" &&
+      "$RATING" != "true" &&
       "$TITLE" != "true" &&
       "$YEAR" != "true" &&
       "$ID" != "true" ]]; then
